{-------------------------------------------------------------------------------
Requirements by Branson Hagerty <bhagerty@thunder.temple.edu>
Program by Scott GrantSmith <ScottMGS@BitSmart.com>

This program and its source is hereby released as Freeware. All legalities
implied. You can use the program. You can change the program. You just can't
claim credit for writing it or charge any money for distributing it. Use this
program at your own risk. While I don't believe that it will harm any computer
that it is run on I do not promise that it won't.

This program was developed using Borland's Delphi 3.

Requirements:
REQUEST FOR TIME/DATE STAMP GENERATOR PROGRAM

One of the most annoying things about writing Shadowrun stuff is coming up with
all of those time date stamps. Invariable the monotony of writing them causes me
to screw up and occasionally create a stamp that says: (25:64:88/09-32-97). Ive
always hoped that somebody would create a program that would generate them for
me and am putting out this call to any programmer who wishes to write a Windows
95 program which will do the following:

Starting at an entered date, the program would have to randomly generate the
hours, minutes, and seconds of a time/date stamp and then put it in the proper
(xx:xx:xx/xx-xx-xx) format. It should then create a list of 15 or 20 (or, hell,
30) time/date stamps which could be individually copied and pasted into a
document.

This may seem rather simple to somebody who knows how to program, but here are a
few requirements which may make things more difficult:

1. The times must fall between 22:00 and 04:00 hours. (I cant picture a
   shadowrunner posting during the day).

2. The times must be RANDOM but SEQUENTIAL.

3. The times must be AT LEAST 30 minutes apart but NO MORE THAN 2 hours apart.
   (In other words, if the program generated 22:32:00 as a time stamp the NEXT
   stamp would have to fall between 23:02:00 and 01:32:00.)

4. Remember that if the time is later than 04:00 the program should continue
   generating stamps at around 22:00 that evening.

The result will be a list of stamps which start on the requested date and
continue 20 stamps into the future. The actual time covered by the 20 stamps
would vary due to the random time distances between them. (One list may generate
stamps which average 45 minutes apart while the next may average 1.5 hours
apart.)

Again, this program would have to be written for Windows 95 (or 3.1, if thats
the best you can do). Experienced programmers should have no problem coming up
with this program. If you feel like writing one, please do. Im sure Paolo would
be more than happy to post it on his archive. And I, personally, will be forever
grateful.

-bh
-------------------------------------------------------------------------------}
unit uBHTimeStamps;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls, Menus;

type
  TBHTimeStamps = class(TForm)
    pLeft: TPanel;
    dtStartDate: TDateTimePicker;
    Label1: TLabel;
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    Settings1: TMenuItem;
    Exit1: TMenuItem;
    Savesettingsonexit1: TMenuItem;
    cbValidStart: TCheckBox;
    lValidEnd: TLabel;
    eMinBetween: TEdit;
    udMinBetween: TUpDown;
    Clear1: TMenuItem;
    bGo: TButton;
    bClearList: TButton;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    eMaxBetween: TEdit;
    udMaxBetween: TUpDown;
    Label6: TLabel;
    Label2: TLabel;
    eQty: TEdit;
    udQty: TUpDown;
    pRight: TPanel;
    eValidStart: TEdit;
    udValidStart: TUpDown;
    Label7: TLabel;
    Label8: TLabel;
    eValidEnd: TEdit;
    udValidEnd: TUpDown;
    Label9: TLabel;
    mTimes: TMemo;
    N1: TMenuItem;
    Savesettings1: TMenuItem;
    N2: TMenuItem;
    Clearlistwhengenerating1: TMenuItem;
    Keepfinaltimestamp1: TMenuItem;
    Help1: TMenuItem;
    Usage1: TMenuItem;
    About1: TMenuItem;
    SetFormat1: TMenuItem;
    N3: TMenuItem;
    Generatealistnow1: TMenuItem;
    procedure Clear1Click(Sender: TObject);
    procedure EditKeyPress(Sender: TObject; var Key: Char);
    procedure eMinBetweenChange(Sender: TObject);
    procedure eMaxBetweenChange(Sender: TObject);
    procedure cbValidStartClick(Sender: TObject);
    procedure bGoClick(Sender: TObject);
    procedure ToggleMenuClick(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
    procedure Savesettings1Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure About1Click(Sender: TObject);
    procedure Usage1Click(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure SetFormat1Click(Sender: TObject);
  protected
    LastTimeStamp : TDateTime;
    function GenerateNextTimeStamp (var LastTimeStamp : TDateTime) : string;
    procedure SaveSettings;
  public
    procedure ReadSettings;
  end;

var
  BHTimeStamps: TBHTimeStamps;

implementation

uses INIFiles, uAbout, uUsage, uDlgFormatting;

{$R *.DFM}

function DateTimeToDate (Orig : TDateTime) : TDateTime;
begin
  Result := Trunc (Orig);
end; // DateTimeToDate

function DateTimeToTime (Orig : TDateTime) : TDateTime;
begin
  Result := Orig - DateTimeToDate (Orig);
end; // DateTimeToTime

procedure TBHTimeStamps.Clear1Click(Sender: TObject);
begin
  mTimes.Clear;
end;

procedure TBHTimeStamps.EditKeyPress(Sender: TObject; var Key: Char);
begin
  if     (Key in [' '..Chr(127)])
     AND NOT (Key in ['0'..'9']) then
  begin
    Key := Chr(0);
    Beep;
  end;
end;

procedure TBHTimeStamps.eMinBetweenChange(Sender: TObject);
begin
  udMaxBetween.Min := udMinBetween.Position;
end;

procedure TBHTimeStamps.eMaxBetweenChange(Sender: TObject);
begin
  udMinBetween.Max := udMaxBetween.Position;
end;

procedure TBHTimeStamps.cbValidStartClick(Sender: TObject);
begin
  eValidStart.Enabled := cbValidStart.Checked;
  udValidStart.Enabled := cbValidStart.Checked;
  Label8.Enabled := cbValidStart.Checked;
  lValidEnd.Enabled := cbValidStart.Checked;
  eValidEnd.Enabled := cbValidStart.Checked;
  udValidEnd.Enabled := cbValidStart.Checked;
  Label9.Enabled := cbValidStart.Checked;
end;

procedure TBHTimeStamps.bGoClick(Sender: TObject);
var i : integer;
begin
  if Clearlistwhengenerating1.Checked then
  begin
    mTimes.Clear;
  end;
  if NOT Keepfinaltimestamp1.Checked then
  begin
    LastTimeStamp := DateTimeToDate (dtStartDate.Date);
  end;
  for i := 1 to udQty.Position do
  begin
    mTimes.Lines.Add (GenerateNextTimeStamp (LastTimeStamp));
  end;
  if Keepfinaltimestamp1.Checked then
  begin
    dtStartDate.Date := DateTimeToDate (LastTimeStamp);
  end;
end;

function TBHTimeStamps.GenerateNextTimeStamp (var LastTimeStamp : TDateTime) : string;

  function SecondsToDays (Secs : integer) : TDateTime;
  begin
    Result := Secs / 60 / 60 / 24;
  end; // SecondsToDays

  function RandSeconds : integer;
  begin
    Result :=   udMinBetween.Position * 60
              + Random ((udMaxbetween.Position - udMinBetween.Position) * 60);
  end; // RandSeconds

var ValidStart, ValidEnd, LastTime : TTime;
    LastDate : TDate;
begin // TBHTimeStamps.GenerateNextTimeStamp
  // increment LastTimeStamp
  LastTimeStamp := LastTimeStamp + SecondsToDays(RandSeconds);

  // validate time
  if cbValidStart.Checked then
  begin
    LastDate := DateTimeToDate(LastTimeStamp);
    LastTime := DateTimeToTime (LastTimeStamp);
    ValidStart := DateTimeToTime (udValidStart.Position / 24);
    ValidEnd := DateTimeToTime (udValidEnd.Position / 24);
    if ValidStart < ValidEnd then
    begin
      if LastTime < ValidStart then
      begin
        LastTimeStamp :=   LastDate
                         + ValidStart
                         + SecondsToDays (  RandSeconds
                                          - (udMinBetween.Position * 60));
      end
      else
      if LastTime > ValidEnd then
      begin
        LastTimeStamp :=   LastDate + 1
                         + ValidStart
                         + SecondsToDays (  RandSeconds
                                          - (udMinBetween.Position * 60));
      end;
    end
    else // ValidEnd < ValidStart
    begin
      if     (LastTime > ValidEnd)
         AND (LastTime < ValidStart) then
      begin
        LastTimeStamp :=   LastDate
                         + ValidStart + (LastTime - ValidEnd);
      end;
    end;
  end;

  // format time stamp
  Result := DlgFormatting.FormatTimeStamp (LastTimeStamp);
end;

procedure TBHTimeStamps.ToggleMenuClick(Sender: TObject);
begin
  (Sender as TMenuItem).Checked := NOT (Sender as TMenuItem).Checked;
end;

procedure TBHTimeStamps.Exit1Click(Sender: TObject);
begin
  Close;
end;

procedure TBHTimeStamps.Savesettings1Click(Sender: TObject);
begin
  SaveSettings;
end;

procedure TBHTimeStamps.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  if Savesettingsonexit1.Checked then
  begin
    SaveSettings;
  end;
end;

procedure TBHTimeStamps.SaveSettings;
var INIFile : TINIFile;
begin
  INIFile := TINIFile.Create (ChangeFileExt (Application.ExeName, '.INI'));
  try
    // Menu settings
    INIFile.WriteBool ('Settings', 'ClearListWhenGenerating', Clearlistwhengenerating1.Checked);
    INIFile.WriteBool ('Settings', 'KeepFinalTimeStamp', Keepfinaltimestamp1.Checked);
    INIFile.WriteBool ('Settings', 'SaveSettingsOnExit', Savesettingsonexit1.Checked);
    // Input settings
    INIFile.WriteString ('Settings', 'StartDate', FormatDateTime ('mm/dd/yyyy', dtStartDate.Date));
    INIFile.WriteBool ('Settings', 'ValidateHourRange', cbValidStart.Checked);
    INIFile.WriteInteger ('Settings', 'ValidStartHour', udValidStart.Position);
    INIFile.WriteInteger ('Settings', 'ValidEndHour', udValidEnd.Position);
    INIFile.WriteInteger ('Settings', 'MinBetween', udMinBetween.Position);
    INIFile.WriteInteger ('Settings', 'MaxBetween', udMaxBetween.Position);
    INIFile.WriteInteger ('Settings', 'Qty', udQty.Position);
    // Clear unused settings
    INIFile.DeleteKey ('Settings', '4DigitYear');
    INIFile.DeleteKey ('Settings', '2DigitMonth');
    INIFile.DeleteKey ('Settings', 'AddSRQuoteDecorations');
    // Date format settings
    INIFile.WriteBool ('DateFormatTab', 'Day1', DlgFormatting.rbDay1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Month1', DlgFormatting.rbMonth1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Year1', DlgFormatting.rbYear1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Day2', DlgFormatting.rbDay2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Month2', DlgFormatting.rbMonth2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Year2', DlgFormatting.rbYear2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Day3', DlgFormatting.rbDay3.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Month3', DlgFormatting.rbMonth3.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Year3', DlgFormatting.rbYear3.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Slash1', DlgFormatting.rbSlash1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Hyphen1', DlgFormatting.rbHyphen1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Period1', DlgFormatting.rbPeriod1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Comma1', DlgFormatting.rbComma1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Space1', DlgFormatting.rbSpace1.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Slash2', DlgFormatting.rbSlash2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Hyphen2', DlgFormatting.rbHyphen2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Period2', DlgFormatting.rbPeriod2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Comma2', DlgFormatting.rbComma2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Space2', DlgFormatting.rbSpace2.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Month1Digit', DlgFormatting.rbMonth1Digit.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Month2Digit', DlgFormatting.rbMonth2Digit.Checked);
    INIFile.WriteBool ('DateFormatTab', 'MonthAbbreviated', DlgFormatting.rbMonthAbbreviated.Checked);
    INIFile.WriteBool ('DateFormatTab', 'MonthFull', DlgFormatting.rbMonthFull.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Day1Digit', DlgFormatting.rbDay1Digit.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Day2Digit', DlgFormatting.rbDay2Digit.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Year2Digit', DlgFormatting.rbYear2Digit.Checked);
    INIFile.WriteBool ('DateFormatTab', 'Year4Digit', DlgFormatting.rbYear4Digit.Checked);
    INIFile.WriteBool ('DateFormatTab', 'DOWNotUsed', DlgFormatting.rbDOWNotUsed.Checked);
    INIFile.WriteBool ('DateFormatTab', 'DOWAbbreviated', DlgFormatting.rbDOWAbbreviated.Checked);
    INIFile.WriteBool ('DateFormatTab', 'DOWFull', DlgFormatting.rbDOWFull.Checked);

    INIFile.WriteBool ('TimeFormatTab', 'Hours1Digit', DlgFormatting.rbHours1Digit.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'Hours2Digit', DlgFormatting.rbHours2Digit.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'Minutes1Digit', DlgFormatting.rbMinutes1Digit.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'Minutes2Digit', DlgFormatting.rbMinutes2Digit.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'SecondsNone', DlgFormatting.rbSecondsNone.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'Seconds1Digit', DlgFormatting.rbSeconds1Digit.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'Seconds2Digit', DlgFormatting.rbSeconds2Digit.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'TimeFormatAMPM', DlgFormatting.rbTimeFormatAMPM.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'TimeFormat24Hour', DlgFormatting.rbTimeFormat24Hour.Checked);
    INIFile.WriteBool ('TimeFormatTab', 'TimeFormatMilitary', DlgFormatting.rbTimeFormatMilitary.Checked);

    INIFile.WriteString ('FormatTab', 'InFront', '"' + DlgFormatting.eInFront.Text + '"');
    INIFile.WriteInteger ('FormatTab', 'FirstElement', DlgFormatting.rgFirstElement.ItemIndex);
    INIFile.WriteString ('FormatTab', 'Between', '"' + DlgFormatting.eBetween.Text + '"');
    INIFile.WriteInteger ('FormatTab', 'LastElement', DlgFormatting.rgLastElement.ItemIndex);
    INIFile.WriteString ('FormatTab', 'After', '"' + DlgFormatting.eAfter.Text + '"');
  finally
    INIFile.Free;
  end;
end;

procedure TBHTimeStamps.ReadSettings;
var INIFile : TINIFile;
begin
  INIFile := TINIFile.Create (ChangeFileExt (Application.ExeName, '.INI'));
  try
    // Menu settings
    Clearlistwhengenerating1.Checked := INIFile.ReadBool ('Settings', 'ClearListWhenGenerating', FALSE);
    Keepfinaltimestamp1.Checked := INIFile.ReadBool ('Settings', 'KeepFinalTimeStamp', TRUE);
    Savesettingsonexit1.Checked := INIFile.ReadBool ('Settings', 'SaveSettingsOnExit', TRUE);
    // Input settings
    dtStartDate.Date := StrToDate (INIFile.ReadString ('Settings', 'StartDate', '1/1/2050'));
    cbValidStart.Checked := INIFile.ReadBool ('Settings', 'ValidateHourRange', TRUE);
    udValidStart.Position := INIFile.ReadInteger ('Settings', 'ValidStartHour', 22);
    udValidEnd.Position := INIFile.ReadInteger ('Settings', 'ValidEndHour', 4);
    udMinBetween.Position := INIFile.ReadInteger ('Settings', 'MinBetween', 30);
    udMaxBetween.Position := INIFile.ReadInteger ('Settings', 'MaxBetween', 120);
    udQty.Position := INIFile.ReadInteger ('Settings', 'Qty', 20);
    // Date format settings
    DlgFormatting.rbDay1.Checked := INIFile.ReadBool ('DateFormatTab', 'Day1', FALSE);
    DlgFormatting.rbMonth1.Checked := INIFile.ReadBool ('DateFormatTab', 'Month1', TRUE);
    DlgFormatting.rbYear1.Checked := INIFile.ReadBool ('DateFormatTab', 'Year1', FALSE);
    DlgFormatting.rbDay2.Checked := INIFile.ReadBool ('DateFormatTab', 'Day2', TRUE);
    DlgFormatting.rbMonth2.Checked := INIFile.ReadBool ('DateFormatTab', 'Month2', FALSE);
    DlgFormatting.rbYear2.Checked := INIFile.ReadBool ('DateFormatTab', 'Year2', FALSE);
    DlgFormatting.rbDay3.Checked := INIFile.ReadBool ('DateFormatTab', 'Day3', FALSE);
    DlgFormatting.rbMonth3.Checked := INIFile.ReadBool ('DateFormatTab', 'Month3', FALSE);
    DlgFormatting.rbYear3.Checked := INIFile.ReadBool ('DateFormatTab', 'Year3', TRUE);
    DlgFormatting.rbSlash1.Checked := INIFile.ReadBool ('DateFormatTab', 'Slash1', FALSE);
    DlgFormatting.rbHyphen1.Checked := INIFile.ReadBool ('DateFormatTab', 'Hyphen1', TRUE);
    DlgFormatting.rbPeriod1.Checked := INIFile.ReadBool ('DateFormatTab', 'Period1', FALSE);
    DlgFormatting.rbComma1.Checked := INIFile.ReadBool ('DateFormatTab', 'Comma1', FALSE);
    DlgFormatting.rbSpace1.Checked := INIFile.ReadBool ('DateFormatTab', 'Space1', FALSE);
    DlgFormatting.rbSlash2.Checked := INIFile.ReadBool ('DateFormatTab', 'Slash2', FALSE);
    DlgFormatting.rbHyphen2.Checked := INIFile.ReadBool ('DateFormatTab', 'Hyphen2', TRUE);
    DlgFormatting.rbPeriod2.Checked := INIFile.ReadBool ('DateFormatTab', 'Period2', FALSE);
    DlgFormatting.rbComma2.Checked := INIFile.ReadBool ('DateFormatTab', 'Comma2', FALSE);
    DlgFormatting.rbSpace2.Checked := INIFile.ReadBool ('DateFormatTab', 'Space2', FALSE);
    DlgFormatting.rbMonth1Digit.Checked := INIFile.ReadBool ('DateFormatTab', 'Month1Digit', FALSE);
    DlgFormatting.rbMonth2Digit.Checked := INIFile.ReadBool ('DateFormatTab', 'Month2Digit', TRUE);
    DlgFormatting.rbMonthAbbreviated.Checked := INIFile.ReadBool ('DateFormatTab', 'MonthAbbreviated', FALSE);
    DlgFormatting.rbMonthFull.Checked := INIFile.ReadBool ('DateFormatTab', 'MonthFull', FALSE);
    DlgFormatting.rbDay1Digit.Checked := INIFile.ReadBool ('DateFormatTab', 'Day1Digit', FALSE);
    DlgFormatting.rbDay2Digit.Checked := INIFile.ReadBool ('DateFormatTab', 'Day2Digit', TRUE);
    DlgFormatting.rbYear2Digit.Checked := INIFile.ReadBool ('DateFormatTab', 'Year2Digit', TRUE);
    DlgFormatting.rbYear4Digit.Checked := INIFile.ReadBool ('DateFormatTab', 'Year4Digit', FALSE);
    DlgFormatting.rbDOWNotUsed.Checked := INIFile.ReadBool ('DateFormatTab', 'DOWNotUsed', TRUE);
    DlgFormatting.rbDOWAbbreviated.Checked := INIFile.ReadBool ('DateFormatTab', 'DOWAbbreviated', FALSE);
    DlgFormatting.rbDOWFull.Checked := INIFile.ReadBool ('DateFormatTab', 'DOWFull', FALSE);

    DlgFormatting.rbHours1Digit.Checked := INIFile.ReadBool ('TimeFormatTab', 'Hours1Digit', FALSE);
    DlgFormatting.rbHours2Digit.Checked := INIFile.ReadBool ('TimeFormatTab', 'Hours2Digit', TRUE);
    DlgFormatting.rbMinutes1Digit.Checked := INIFile.ReadBool ('TimeFormatTab', 'Minutes1Digit', FALSE);
    DlgFormatting.rbMinutes2Digit.Checked := INIFile.ReadBool ('TimeFormatTab', 'Minutes2Digit', TRUE);
    DlgFormatting.rbSecondsNone.Checked := INIFile.ReadBool ('TimeFormatTab', 'SecondsNone', FALSE);
    DlgFormatting.rbSeconds1Digit.Checked := INIFile.ReadBool ('TimeFormatTab', 'Seconds1Digit', FALSE);
    DlgFormatting.rbSeconds2Digit.Checked := INIFile.ReadBool ('TimeFormatTab', 'Seconds2Digit', TRUE);
    DlgFormatting.rbTimeFormatAMPM.Checked := INIFile.ReadBool ('TimeFormatTab', 'TimeFormatAMPM', FALSE);
    DlgFormatting.rbTimeFormat24Hour.Checked := INIFile.ReadBool ('TimeFormatTab', 'TimeFormat24Hour', TRUE);
    DlgFormatting.rbTimeFormatMilitary.Checked := INIFile.ReadBool ('TimeFormatTab', 'TimeFormatMilitary', FALSE);

    DlgFormatting.eInFront.Text := INIFile.ReadString ('FormatTab', 'InFront', '>>>>>[comment]<<<<< - name (');
    DlgFormatting.rgFirstElement.ItemIndex := INIFile.ReadInteger ('FormatTab', 'FirstElement', 0);
    DlgFormatting.eBetween.Text := INIFile.ReadString ('FormatTab', 'Between', '/');
    DlgFormatting.rgLastElement.ItemIndex := INIFile.ReadInteger ('FormatTab', 'LastElement', 1);
    DlgFormatting.eAfter.Text := INIFile.ReadString ('FormatTab', 'After', ')');

    LastTimeStamp := DateTimeToDate (dtStartDate.Date);
  finally
    INIFile.Free;
  end;
end;

procedure TBHTimeStamps.About1Click(Sender: TObject);
begin
  AboutBox := TAboutBox.Create (Self);
  try
    AboutBox.ShowModal;
  finally
    AboutBox.Free;
  end;
end;

procedure TBHTimeStamps.Usage1Click(Sender: TObject);
begin
  UsageBox := TUsageBox.Create (Self);
  try
    UsageBox.ShowModal;
  finally
    UsageBox.Free;
  end;
end;

procedure TBHTimeStamps.FormResize(Sender: TObject);
begin
  if ClientHeight < bGo.Top + bGo.Height + 9 then
  begin
    ClientHeight := bGo.Top + bGo.Height + 9;
  end;
  if Width < 375 then
  begin
    Width := 375;
  end;
end;

procedure TBHTimeStamps.SetFormat1Click(Sender: TObject);
begin
  DlgFormatting.ShowModal;
end;

initialization
  Randomize;
end.
