unit uDlgFormatting;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ComCtrls, ExtCtrls;

type
  TDlgFormatting = class(TForm)
    Panel1: TPanel;
    Panel2: TPanel;
    PageControl1: TPageControl;
    tsDateFormat: TTabSheet;
    tsTimeFormat: TTabSheet;
    tsPutItAllTogether: TTabSheet;
    OKBtn: TButton;
    CancelBtn: TButton;
    HelpBtn: TButton;
    gbFirst: TGroupBox;
    rbDay1: TRadioButton;
    rbMonth1: TRadioButton;
    rbYear1: TRadioButton;
    gbBetween: TGroupBox;
    rbDay2: TRadioButton;
    rbMonth2: TRadioButton;
    rbYear2: TRadioButton;
    gbLast: TGroupBox;
    rbDay3: TRadioButton;
    rbMonth3: TRadioButton;
    rbYear3: TRadioButton;
    gbMonth: TGroupBox;
    rbMonth1Digit: TRadioButton;
    rbMonth2Digit: TRadioButton;
    rbMonthAbbreviated: TRadioButton;
    rbMonthFull: TRadioButton;
    gbDayLength: TGroupBox;
    rbDay1Digit: TRadioButton;
    rbDay2Digit: TRadioButton;
    gbDayOfWeek: TGroupBox;
    rbDOWNotUsed: TRadioButton;
    rbDOWAbbreviated: TRadioButton;
    rbDOWFull: TRadioButton;
    lDateExample: TLabel;
    gbYearLength: TGroupBox;
    rbYear2Digit: TRadioButton;
    rbYear4Digit: TRadioButton;
    gbSeparator1: TGroupBox;
    rbSlash1: TRadioButton;
    rbHyphen1: TRadioButton;
    rbPeriod1: TRadioButton;
    rbSpace1: TRadioButton;
    gbSeparator2: TGroupBox;
    rbSlash2: TRadioButton;
    rbHyphen2: TRadioButton;
    rbPeriod2: TRadioButton;
    rbSpace2: TRadioButton;
    rbComma1: TRadioButton;
    rbComma2: TRadioButton;
    gbHours: TGroupBox;
    rbHours1Digit: TRadioButton;
    rbHours2Digit: TRadioButton;
    gbMinutes: TGroupBox;
    rbMinutes1Digit: TRadioButton;
    rbMinutes2Digit: TRadioButton;
    gbHourFormat: TGroupBox;
    rbTimeFormatAMPM: TRadioButton;
    rbTimeFormat24Hour: TRadioButton;
    rbTimeFormatMilitary: TRadioButton;
    lTimeExample: TLabel;
    gbSeconds: TGroupBox;
    rbSeconds1Digit: TRadioButton;
    rbSeconds2Digit: TRadioButton;
    rbSecondsNone: TRadioButton;
    Label1: TLabel;
    eInFront: TEdit;
    rgFirstElement: TRadioGroup;
    Label2: TLabel;
    eBetween: TEdit;
    rgLastElement: TRadioGroup;
    Label3: TLabel;
    eAfter: TEdit;
    lExample: TLabel;
    procedure DateFormatClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure TimeFormatClick(Sender: TObject);
    procedure FormatClick(Sender: TObject);
  private
    { Private declarations }
    FDateFormat : string;
    FTimeFormat : string;
    procedure ValidateDateFormatOrder;
    procedure SetDateFormat;
    procedure ReformatDateExample;
    procedure SetTimeFormat;
    procedure ReformatTimeExample;
    procedure ReformatExample;
  public
    { Public declarations }
    function FormatDate (dDate : TDateTime) : string;
    function FormatTime (dTime : TDateTime) : string;
    function FormatTimeStamp (dDateTime : TDateTime) : string;
    property DateFormat : string read FDateFormat;
    property TimeFormat : string read FTimeFormat;
  end;

var
  DlgFormatting: TDlgFormatting;

implementation

uses uBHTimeStamps;

{$R *.DFM}

procedure TDlgFormatting.FormCreate(Sender: TObject);
begin
  BHTimeStamps.ReadSettings;

  ReformatDateExample;
  ReformatTimeExample;
  ReformatExample;
end;

procedure TDlgFormatting.DateFormatClick (Sender: TObject);
begin
  ReformatDateExample;
end; // TDlgFormatting.DateFormatClick

procedure TDlgFormatting.ValidateDateFormatOrder;
begin
  if     rbDay1.Checked
     AND rbDay2.Checked then rbMonth2.Checked := TRUE;
  if     rbDay1.Checked
     AND rbDay3.Checked then rbMonth3.Checked := TRUE;
  if     rbMonth1.Checked
     AND rbMonth2.Checked then rbYear2.Checked := TRUE;
  if     rbMonth1.Checked
     AND rbMonth3.Checked then rbYear3.Checked := TRUE;
  if     rbYear1.Checked
     AND rbYear2.Checked then rbDay2.Checked := TRUE;
  if     rbYear1.Checked
     AND rbYear3.Checked then rbDay3.Checked := TRUE;
end; // TDlgFormatting.ValidateDateFormatOrder

procedure TDlgFormatting.SetDateFormat;

  function GetDayFormat : string;
  begin
    if rbDay1Digit.Checked
      then Result := 'd'
      else Result := 'dd';
  end;

  function GetMonthFormat : string;
  begin
    if rbMonth1Digit.Checked
      then Result := 'm'
      else
      if rbMonth2Digit.Checked
        then Result := 'mm'
        else
        if rbMonthAbbreviated.Checked
          then Result := 'mmm'
          else Result := 'mmmm';
  end;

  function GetYearFormat : string;
  begin
    if rbYear2Digit.Checked
      then Result := 'yy'
      else Result := 'yyyy'
  end;

  function GetSeparator1 : string;
  begin
    if rbSlash1.Checked
      then Result := '"/"'
      else
      if rbHyphen1.Checked
        then Result := '"-"'
        else
        if rbPeriod1.Checked
          then Result := '"."'
          else
          if rbComma1.Checked
            then Result := '", "'
            else Result := ' ';
  end;

  function GetSeparator2 : string;
  begin
    if rbSlash2.Checked
      then Result := '"/"'
      else
      if rbHyphen2.Checked
        then Result := '"-"'
        else
        if rbPeriod2.Checked
          then Result := '"."'
          else
          if rbComma2.Checked
            then Result := '", "'
            else Result := ' ';
  end;

begin // TDlgFormatting.SetDateFormat
  ValidateDateFormatOrder;
  // Set Day of Week
  if rbDOWNotUsed.Checked
    then FDateFormat := ''
    else
    if rbDOWAbbreviated.Checked
      then FDateFormat := 'ddd, '
      else FDateFormat := 'dddd, ';
  // Set first date entry
  if rbDay1.Checked
    then FDateFormat := FDateFormat + GetDayFormat + GetSeparator1
    else
    if rbMonth1.Checked
      then FDateFormat := FDateFormat + GetMonthFormat + GetSeparator1
      else FDateFormat := FDateFormat + GetYearFormat + GetSeparator1;
  // Set second date entry
  if rbDay2.Checked
    then FDateFormat := FDateFormat + GetDayFormat + GetSeparator2
    else
    if rbMonth2.Checked
      then FDateFormat := FDateFormat + GetMonthFormat + GetSeparator2
      else FDateFormat := FDateFormat + GetYearFormat + GetSeparator2;
  // Set third date entry
  if rbDay3.Checked
    then FDateFormat := FDateFormat + GetDayFormat
    else
    if rbMonth3.Checked
      then FDateFormat := FDateFormat + GetMonthFormat
      else FDateFormat := FDateFormat + GetYearFormat;
end; // TDlgFormatting.SetDateFormat

procedure TDlgFormatting.ReformatDateExample;
begin
  SetDateFormat;
  lDateExample.Caption := 'Example: ' + FormatDate (StrToDate ('8/9/2057'));
end; // TDlgFormatting.ReformatDateExample

function TDlgFormatting.FormatDate (dDate : TDateTime) : string;
begin
  Result := FormatDateTime (FDateFormat, dDate);
end; // TDlgFormatting.FormatDate

procedure TDlgFormatting.TimeFormatClick(Sender: TObject);
begin
  ReformatTimeExample;
end;

procedure TDlgFormatting.ReformatTimeExample;
begin
  SetTimeFormat;
  lTimeExample.Caption := 'Example: ' + FormatTime (0.6667);
end; // TDlgFormatting.ReformatTimeExample

procedure TDlgFormatting.SetTimeFormat;

  function GetSeparator : string;
  begin
    if rbTimeFormatMilitary.Checked
      then Result := ''
      else Result := ':';
  end;

  function GetHourFormat : string;
  begin
    if    rbTimeFormatMilitary.Checked
       OR rbHours2Digit.Checked
      then Result := 'hh'
      else Result := 'h';
  end;

  function GetMinuteFormat : string;
  begin
    if    rbTimeFormatMilitary.Checked
       OR rbMinutes2Digit.Checked
      then Result := GetSeparator + 'nn'
      else Result := GetSeparator + 'n';
  end;

  function GetSecondFormat : string;
  begin
    if    rbTimeFormatMilitary.Checked
       OR rbSeconds2Digit.Checked
      then Result := GetSeparator + 'ss'
      else
      if rbSeconds1Digit.Checked
        then Result := GetSeparator + 's'
        else Result := '';
  end;

  function GetAMPMFormat : string;
  begin
    if rbTimeFormatAMPM.Checked
      then Result := ' ampm'
      else Result := ''
  end;

begin // TDlgFormatting.SetTimeFormat
  FTimeFormat :=   GetHourFormat + GetMinuteFormat
                 + GetSecondFormat + GetAMPMFormat;
end; // TDlgFormatting.SetTimeFormat

function TDlgFormatting.FormatTime (dTime : TDateTime) : string;
begin
  Result := FormatDateTime (FTimeFormat, dTime);
end; // TDlgFormatting.FormatTime

procedure TDlgFormatting.FormatClick(Sender: TObject);
begin
  ReformatExample;
end;

procedure TDlgFormatting.ReformatExample;
begin
  lExample.Caption :=   'Example: '
                      + FormatTimeStamp (StrToDate ('8/9/2057') + 0.6667);
end; // TDlgFormatting.ReformatExample

function TDlgFormatting.FormatTimeStamp (dDateTime : TDateTime) : string;
begin
  Result := eInFront.Text;
  case rgFirstElement.ItemIndex of
    0: Result := Result + FormatDateTime (FTimeFormat, dDateTime);
    1: Result := Result + FormatDateTime (FDateFormat, dDateTime);
  end;
  Result := Result + eBetween.Text;
  case rgLastElement.ItemIndex of
    0: Result := Result + FormatDateTime (FTimeFormat, dDateTime);
    1: Result := Result + FormatDateTime (FDateFormat, dDateTime);
  end;
  Result := Result + eAfter.Text;
end; // TDlgFormatting.FormatTime

end.

